/* Copyright 1996, Jan D. Wolter and Steven R. Weiss, All Rights Reserved. */

/* Read conference Configuration files.
 *
 * Mar 15, 1993 - Jan Wolter:  Original version
 * May 29, 1993 - Jan Wolter:  Revised to read conference modes.
 * Dec  2, 1995 - Jan Wolter:  Ansification
 * Jan  2, 1996 - Jan Wolter:  BackTalk version
 */

#include "backtalk.h"

#include "ps_config.h"

#define CONFIG		"/config"

/* READCONFIG -- Given the directory path for a conference, return the name
 * of the participation file, the list of fairwitnesses, the  mode of the
 * conference and the conference title.  Modes 4, 5 and 6 indicate closed
 * conferences of various kinds.  Pfname and fw point to storage areas of at
 * least BFSZ bytes.  Title set to null if no conference title is set or is
 * set to point to a conference title in static storage.  If pfname, fw, mode,
 * or title are passed in as NULL, they aren't set.
 */

void readconfig(char *dir, char *pfname, char *fw, int *mode, char **title)
{
FILE *fp;
static char buf[BFSZ];
char *b;

	strcpy(buf,dir);
	strcat(buf,CONFIG);

	if ((fp= fopen(buf,"r")) == NULL)
		die("could not open %s",buf);

	/* Read and check magic code number */
	if (fgets(buf,BFSZ,fp) == NULL || strcmp(buf,"!<pc02>\n"))
		die("Bad version number in %s", buf);

	/* Read participation file name */
	if (fgets(buf,BFSZ,fp) == NULL)
		goto weird;

	if ((b= strchr(buf,'\n')) == NULL)
		goto weird;
	*b = '\0';
	if (pfname != NULL) strcpy(pfname,buf);

	/* Read the time limit line - this is always zero, so who cares? */
	if (fgets(buf,BFSZ,fp) == NULL)
		goto weird;

	/* Read the list of fairwitnesses */
	if (fgets(buf,BFSZ,fp) == NULL)
		goto weird;

	if ((b= strchr(buf,'\n')) == NULL)
		goto weird;
	*b = '\0';
	if (fw != NULL) strcpy(fw,buf);

	/* Read the mode line */
	if (fgets(buf,BFSZ,fp) == NULL)
	{
		if (mode != NULL) *mode= 0;
	}
	else
	{
		if (mode != NULL) *mode= atoi(buf);
	}

	/* Read the conference title */
	if (title != NULL)
		{
		if (fgets(buf,BFSZ,fp) == NULL)
			*title= NULL;
		else
		{
			if ((b= strchr(buf,'\n')) == NULL)
				goto weird;
			*b = '\0';
			*title= buf;
		}
	}

	fclose(fp);
	return;

weird:	die("conference configuration file in weird format\n");
}
